==> checker-3.5.0.jar: annotated-jdk/src/java.base/share/classes/java/io/LineNumberReader.java <==
/*
 * Copyright (c) 1996, 2011, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package java.io;

import org.checkerframework.checker.index.qual.GTENegativeOne;
import org.checkerframework.checker.index.qual.IndexOrHigh;
import org.checkerframework.checker.index.qual.LTEqLengthOf;
import org.checkerframework.checker.index.qual.LTLengthOf;
import org.checkerframework.checker.index.qual.NonNegative;
import org.checkerframework.checker.lock.qual.GuardSatisfied;
import org.checkerframework.checker.nullness.qual.Nullable;
import org.checkerframework.framework.qual.AnnotatedFor;

@AnnotatedFor({ "lock", "nullness", "index" })
public class LineNumberReader extends BufferedReader {

    public LineNumberReader(Reader in) {
    }

    public LineNumberReader(Reader in, @NonNegative int sz) {
    }

    public void setLineNumber(@GuardSatisfied LineNumberReader this, @NonNegative int lineNumber);

    @NonNegative
    public int getLineNumber(@GuardSatisfied LineNumberReader this);

    @SuppressWarnings("fallthrough")
    public int read(@GuardSatisfied LineNumberReader this) throws IOException;

    @SuppressWarnings("fallthrough")
    @GTENegativeOne
    @LTEqLengthOf({ "#1" })
    public int read(@GuardSatisfied LineNumberReader this, char[] cbuf, @IndexOrHigh({ "#1" }) int off, @LTLengthOf(value = { "#1" }, offset = { "#2 - 1" }) @NonNegative int len) throws IOException;

    @Nullable
    public String readLine(@GuardSatisfied LineNumberReader this) throws IOException;

    @NonNegative
    public long skip(@GuardSatisfied LineNumberReader this, @NonNegative long n) throws IOException;

    public void mark(@GuardSatisfied LineNumberReader this, @NonNegative int readAheadLimit) throws IOException;

    public void reset(@GuardSatisfied LineNumberReader this) throws IOException;
}

==> checker-3.49.5.jar: annotated-jdk/src/java.base/share/classes/java/io/LineNumberReader.java <==
/*
 * Copyright (c) 1996, 2021, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package java.io;

import org.checkerframework.checker.index.qual.GTENegativeOne;
import org.checkerframework.checker.index.qual.IndexOrHigh;
import org.checkerframework.checker.index.qual.LTEqLengthOf;
import org.checkerframework.checker.index.qual.LTLengthOf;
import org.checkerframework.checker.index.qual.NonNegative;
import org.checkerframework.checker.lock.qual.GuardSatisfied;
import org.checkerframework.checker.mustcall.qual.MustCallAlias;
import org.checkerframework.checker.nullness.qual.Nullable;
import org.checkerframework.framework.qual.AnnotatedFor;

@AnnotatedFor({ "index", "lock", "mustcall", "nullness" })
public class LineNumberReader extends BufferedReader {

    @MustCallAlias
    public LineNumberReader(@MustCallAlias Reader in) {
    }

    @MustCallAlias
    public LineNumberReader(@MustCallAlias Reader in, @NonNegative int sz) {
    }

    public void setLineNumber(@GuardSatisfied LineNumberReader this, @NonNegative int lineNumber);

    @NonNegative
    public int getLineNumber(@GuardSatisfied LineNumberReader this);

    @SuppressWarnings("fallthrough")
    public int read(@GuardSatisfied LineNumberReader this) throws IOException;

    @SuppressWarnings("fallthrough")
    @GTENegativeOne
    @LTEqLengthOf({ "#1" })
    public int read(@GuardSatisfied LineNumberReader this, char[] cbuf, @IndexOrHigh({ "#1" }) int off, @LTLengthOf(value = { "#1" }, offset = { "#2 - 1" }) @NonNegative int len) throws IOException;

    @Nullable
    public String readLine(@GuardSatisfied LineNumberReader this) throws IOException;

    @NonNegative
    public long skip(@GuardSatisfied LineNumberReader this, @NonNegative long n) throws IOException;

    public void mark(@GuardSatisfied LineNumberReader this, @NonNegative int readAheadLimit) throws IOException;

    public void reset(@GuardSatisfied LineNumberReader this) throws IOException;
}
